<?php
/**
 * @package        Joomla
 * @subpackage     Membership Pro
 * @author         Stefan Poensgen
 * @copyright      Copyright (C) 2012 - 2018 Ossolution Team
 * @license        GNU General Public License version 2 or later
 */
// no direct access
defined('_JEXEC') or die;

require_once JPATH_ROOT . '/components/com_osmembership/plugins/os_paypal.php';

class os_paypal_crs extends os_paypal
{

    /**
     * PayPal API Url
     *
     * @var string
     *
     * @since 1.0
     */
    protected $apiUrl;

    /**
     * PayPal API User
     *
     * @var string
     *
     * @since 1.0
     */
    protected $apiUser;

    /**
     * PayPal API Password
     *
     * @var string
     *
     * @since 1.0
     */
    protected $apiPassword;

    /**
     * PayPal API Signature
     *
     * @var string
     *
     * @since 1.0
     */
    protected $apiSignature;

    /**
     * Constructor
     *
     * @param JRegistry $params
     * @param array $config
     *
     * @since 1.0
     */
    public function __construct($params, $config = array())
    {
        parent::__construct($params, $config);

        if ($this->mode) {
            $this->apiUrl = 'https://api-3t.paypal.com/nvp';
            $this->apiUser = $params->get('paypal_api_user');
            $this->apiPassword = $params->get('paypal_api_password');
            $this->apiSignature = $params->get('paypal_api_signature');
        } else {
            $this->apiUrl = 'https://api-3t.sandbox.paypal.com/nvp';
            $this->apiUser = $params->get('paypal_api_user_sandbox');
            $this->apiPassword = $params->get('paypal_api_password_sandbox');
            $this->apiSignature = $params->get('paypal_api_signature_sandbox');
        }

    }

    /**
     * Cancel recurring subscription
     *
     * @param $row
     *
     * @return bool
     * @throws Exception
     *
     * @since 1.0
     */
    public function cancelSubscription($row)
    {
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_VERBOSE, 1);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_URL, $this->apiUrl);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query(array(
            'USER' => $this->apiUser,
            'PWD' => $this->apiPassword,
            'SIGNATURE' => $this->apiSignature,
            'VERSION' => '108',
            'METHOD' => 'ManageRecurringPaymentsProfileStatus',
            'PROFILEID' => $row->subscription_id,
            'ACTION' => 'Cancel'
        )));

        $response = curl_exec($curl);
        curl_close($curl);

        $nvp = array();

        if (preg_match_all('/(?<name>[^\=]+)\=(?<value>[^&]+)&?/', $response, $matches)) {
            foreach ($matches['name'] as $offset => $name) {
                $nvp[$name] = urldecode($matches['value'][$offset]);
            }
        }

        if ($nvp['ACK'] == 'Success') {
            JFactory::getApplication()->triggerEvent('onCancelSubscription', array($row));
            return true;
        } else {
            JFactory::getApplication()->enqueueMessage($nvp['L_LONGMESSAGE0'], 'error');
            return false;
        }
    }

}
